      subroutine get_thephi (pftimg, pfts, pft_avgs, nrot, nannuli, 
     1     nview_mod, sq2, jcut, pixres_min, pixres_max, ccpft, ann_lo, 
     2     ann_hi, var, avg, sq1, index)
      
C     determines the best theta,phi orientation
C     
C     may 1992  purdue university vax 8550, t. baker
C     modified 18-aug-1993 by t. baker.
C     modified xx_apr-1996 by dmb (fixed bug in extended output).
C     modified 23-apr-1998 by t. baker (renamed from pftcc_gettp)
C     modified 14-aug-2006, r sinkovits, general cleanup

      implicit none
      
      integer, intent(in)  :: jcut, nrot, nannuli, nview_mod
      integer, intent(in)  :: ann_lo, ann_hi
      real, intent(in)     :: pftimg((nrot/4),nannuli)
      real, intent(in)     :: pfts((nrot/4),nannuli,nview_mod)
      real, intent(in)     :: pft_avgs(nview_mod)
      real, intent(in)     :: pixres_min, pixres_max
      logical, intent(in)    :: var((nrot/4),nannuli)
      real, intent(in)     :: avg, sq1, sq2(nview_mod)

      integer, intent(out) :: index
      real, intent(out)    :: ccpft

      integer j, id, jn_lb, jn_ub, ir, r
      logical all_var_true
      real    tot, ccor, npts, div1, div2, twopir, pi
      
      pi = acos(-1.0)
      ccpft = -huge(ccpft)
      
C     Determine whether or not all elements of array var are true. If
C     so, inner most computational loop can be streamlined

      all_var_true = all(var)   ! Fortran 90 intrinsic function

      do id = 1,nview_mod
         npts = 0.0
         tot  = 0.0

         do ir = ann_lo,ann_hi
            r      = min(nannuli, ir + 1)
            twopir = 2.0*pi*float(ir)

            jn_lb = max(1, jcut, ceiling(twopir/pixres_min))
            jn_ub = min(nrot/4-1, floor(twopir/pixres_max))

            if(all_var_true) then
               do j = jn_lb+1, jn_ub+1
                  tot  = tot + pftimg(j,r)*pfts(j,r,id)
               enddo
               npts = npts + (jn_ub - jn_lb + 1)
            else
               do j = jn_lb+1, jn_ub+1
                  if(var(j,r)) then
                     npts = npts + 1.0
                     tot  = tot + pftimg(j,r)*pfts(j,r,id)
                  endif
               enddo
            endif

         enddo

         div1     = sqrt (sq1 - npts*(avg**2))
         div2     = sqrt (sq2(id)-npts*(pft_avgs(id)**2))
         ccor = (tot-avg*pft_avgs(id)*npts)/(div1*div2)

         if(ccor > ccpft) then
            ccpft = ccor
            index = id
         endif
      enddo

      return
      end subroutine get_thephi
