      function ctf_firstpeak ( defocus, wavelength, pixel_size,
     $     idim, cs, units)

C     Determine the location of the first peak in the CTF
C
C     Author Wei Zhang
C     General cleanup and conversion to function, R. Sinkovits (11/15/2006)

        implicit none

        integer, intent(in) :: idim, units
        real, intent(in)    ::defocus, wavelength, pixel_size, cs

        real ctf_firstpeak
        double precision  fw, a, b, c

C     Perform conversions
C     - cs from mm to Angstroms
C     - defocus from micron to Angstrom
C     - wavelength from nm to Angstroms

        a = cs * 10000000.0
        b = -2.0 * defocus * 10000.0
        c = wavelength * 10.0

C     More accurate method for calculating location of 1st peak
C        pi = acos(-1.0)
C        angle = asin(amp_fac)
C        c = wavelength*10.0*(1.0 - (2.0*angle)/pi)

        fw      = sqrt((-sqrt(b*b - 4.0*a*c) - b)/(2.0*a))

C     If units == 2, then pixel_size is in nm and must be converted to
C     Angstroms. Otherwise, pixel_size is already in Angstroms

        if(units == 2) then
           ctf_firstpeak = fw*(pixel_size*10.0*idim)/(10.0*wavelength)
        else
           ctf_firstpeak = fw*(pixel_size*idim)/(10.0*wavelength)
        endif
        
        return
        end function ctf_firstpeak
